Delay

Struct Delay 

pub struct Delay { /* private fields */ }
A future representing the notification that an elapsed duration has occurred.

This is created through the Delay::new method indicating when the future should fire. Note that these futures are not intended for high resolution timers, but rather they will likely fire some granularity after the exact instant that they’re otherwise indicated to fire at.

Implementations

Source

impl Delay

pub fn new(dur: Duration) -> Delay

Creates a new future which will fire at dur time into the future.

The returned object will be bound to the default timer for this thread. The default timer will be spun up in a helper thread on first use.

pub fn reset(&mut self, dur: Duration)

Resets this timeout to an new timeout which will fire at the time specified by at.